pychemia.test package
=====================

.. automodule:: pychemia.test
    :members:
    :undoc-members:
    :show-inheritance:

Submodules
----------

pychemia.test.doctest_2to3 module
---------------------------------

.. automodule:: pychemia.test.doctest_2to3
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.test.test_00 module
----------------------------

.. automodule:: pychemia.test.test_00
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.test.test_bin module
-----------------------------

.. automodule:: pychemia.test.test_bin
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.test.test_zexample1 module
-----------------------------------

.. automodule:: pychemia.test.test_zexample1
    :members:
    :undoc-members:
    :show-inheritance:

pychemia.test.test_zexample2 module
-----------------------------------

.. automodule:: pychemia.test.test_zexample2
    :members:
    :undoc-members:
    :show-inheritance:


